#region Using declarations
using System;
using System.ComponentModel;
using System.Diagnostics;
using System.Drawing;
using System.Drawing.Drawing2D;
using System.Xml.Serialization;
using NinjaTrader.Cbi;
using NinjaTrader.Data;
using NinjaTrader.Gui.Chart;
#endregion

// This namespace holds all indicators and is required. Do not change it.
namespace NinjaTrader.Indicator
{
    /// <summary>
    /// Version 1.0 01/19/2009
    /// </summary>
    [Description("RAVIFXFisher Created by Luis Guilherme Damiani. Converted to NinjaTrader by Elliott Wave.")]
    public class RAVIFXFisher : Indicator
    {
        #region Variables
        // Wizard generated variables
            private int mAfast = 4; // Default setting for MAfast
            private int mAslow = 49; // Default setting for MAslow
            private double trigger = 0.09; // Default setting for Trigger
		
			private double MAValue =0;
			private double IFish =0;
        // User defined variables (add any user defined variables below)
        #endregion

        /// <summary>
        /// This method is used to configure the indicator and is called once before any bar data is loaded.
        /// </summary>
        protected override void Initialize()
        {
            Add(new Plot(Color.FromKnownColor(KnownColor.MediumSeaGreen), PlotStyle.Line, "RAVIfxFish"));
            Add(new Line(Color.DarkViolet, trigger, "HiTrigger"));
			Add(new Line(Color.DarkViolet, -1 * trigger , "LowTrigger"));
			
			Add(new Line(Color.DarkGray, 0 , "ZeroLine"));
			
			Plots[0].Pen.Width = 2;
			Lines[0].Pen.Width = 1;
			Lines[1].Pen.Width = 1;
			Lines[2].Pen.DashStyle = DashStyle.Dash;
			Lines[2].Pen.Width = 2;
			
			
			CalculateOnBarClose	= true;
            Overlay				= false;
            PriceTypeSupported	= false;
			//PriceType = PriceType.Typical;
        }

        /// <summary>
        /// Called on each bar update event (incoming tick)
        /// </summary>
        protected override void OnBarUpdate()
        {
            
			if (CurrentBar < mAslow)
			{
				return;
			}
	    
			MAValue = 100 * ((WMA(Typical, MAfast)[0]- WMA(Typical, MAslow)[0]) * ATR(MAfast)[0] / WMA(Typical,MAslow)[0] / ATR(MAslow)[0]);
			
			IFish=(Math.Exp(2*MAValue)-1)/(Math.Exp(2*MAValue)+1);
			RAVIfxFish.Set(IFish);
        }

        #region Properties
        [Browsable(false)]	// this line prevents the data series from being displayed in the indicator properties dialog, do not remove
        [XmlIgnore()]		// this line ensures that the indicator can be saved/recovered as part of a chart template, do not remove
        public DataSeries RAVIfxFish
        {
            get { return Values[0]; }
        }

        [Description("")]
        [Category("Parameters")]
        public int MAfast
        {
            get { return mAfast; }
            set { mAfast = Math.Max(1, value); }
        }

        [Description("")]
        [Category("Parameters")]
        public int MAslow
        {
            get { return mAslow; }
            set { mAslow = Math.Max(1, value); }
        }

        [Description("")]
        [Category("Parameters")]
        public double Trigger
        {
            get { return trigger; }
            set { trigger = Math.Max(0.001, value); }
        }

        #endregion
    }
}

#region NinjaScript generated code. Neither change nor remove.
// This namespace holds all indicators and is required. Do not change it.
namespace NinjaTrader.Indicator
{
    public partial class Indicator : IndicatorBase
    {
        private RAVIFXFisher[] cacheRAVIFXFisher = null;

        private static RAVIFXFisher checkRAVIFXFisher = new RAVIFXFisher();

        /// <summary>
        /// RAVIFXFisher Created by Luis Guilherme Damiani. Converted to NinjaTrader by Elliott Wave.
        /// </summary>
        /// <returns></returns>
        public RAVIFXFisher RAVIFXFisher(int mAfast, int mAslow, double trigger)
        {
            return RAVIFXFisher(Input, mAfast, mAslow, trigger);
        }

        /// <summary>
        /// RAVIFXFisher Created by Luis Guilherme Damiani. Converted to NinjaTrader by Elliott Wave.
        /// </summary>
        /// <returns></returns>
        public RAVIFXFisher RAVIFXFisher(Data.IDataSeries input, int mAfast, int mAslow, double trigger)
        {
            checkRAVIFXFisher.MAfast = mAfast;
            mAfast = checkRAVIFXFisher.MAfast;
            checkRAVIFXFisher.MAslow = mAslow;
            mAslow = checkRAVIFXFisher.MAslow;
            checkRAVIFXFisher.Trigger = trigger;
            trigger = checkRAVIFXFisher.Trigger;

            if (cacheRAVIFXFisher != null)
                for (int idx = 0; idx < cacheRAVIFXFisher.Length; idx++)
                    if (cacheRAVIFXFisher[idx].MAfast == mAfast && cacheRAVIFXFisher[idx].MAslow == mAslow && Math.Abs(cacheRAVIFXFisher[idx].Trigger - trigger) <= double.Epsilon && cacheRAVIFXFisher[idx].EqualsInput(input))
                        return cacheRAVIFXFisher[idx];

            RAVIFXFisher indicator = new RAVIFXFisher();
            indicator.BarsRequired = BarsRequired;
            indicator.CalculateOnBarClose = CalculateOnBarClose;
            indicator.Input = input;
            indicator.MAfast = mAfast;
            indicator.MAslow = mAslow;
            indicator.Trigger = trigger;
            indicator.SetUp();

            RAVIFXFisher[] tmp = new RAVIFXFisher[cacheRAVIFXFisher == null ? 1 : cacheRAVIFXFisher.Length + 1];
            if (cacheRAVIFXFisher != null)
                cacheRAVIFXFisher.CopyTo(tmp, 0);
            tmp[tmp.Length - 1] = indicator;
            cacheRAVIFXFisher = tmp;
            Indicators.Add(indicator);

            return indicator;
        }

    }
}

// This namespace holds all market analyzer column definitions and is required. Do not change it.
namespace NinjaTrader.MarketAnalyzer
{
    public partial class Column : ColumnBase
    {
        /// <summary>
        /// RAVIFXFisher Created by Luis Guilherme Damiani. Converted to NinjaTrader by Elliott Wave.
        /// </summary>
        /// <returns></returns>
        [Gui.Design.WizardCondition("Indicator")]
        public Indicator.RAVIFXFisher RAVIFXFisher(int mAfast, int mAslow, double trigger)
        {
            return _indicator.RAVIFXFisher(Input, mAfast, mAslow, trigger);
        }

        /// <summary>
        /// RAVIFXFisher Created by Luis Guilherme Damiani. Converted to NinjaTrader by Elliott Wave.
        /// </summary>
        /// <returns></returns>
        public Indicator.RAVIFXFisher RAVIFXFisher(Data.IDataSeries input, int mAfast, int mAslow, double trigger)
        {
            return _indicator.RAVIFXFisher(input, mAfast, mAslow, trigger);
        }

    }
}

// This namespace holds all strategies and is required. Do not change it.
namespace NinjaTrader.Strategy
{
    public partial class Strategy : StrategyBase
    {
        /// <summary>
        /// RAVIFXFisher Created by Luis Guilherme Damiani. Converted to NinjaTrader by Elliott Wave.
        /// </summary>
        /// <returns></returns>
        [Gui.Design.WizardCondition("Indicator")]
        public Indicator.RAVIFXFisher RAVIFXFisher(int mAfast, int mAslow, double trigger)
        {
            return _indicator.RAVIFXFisher(Input, mAfast, mAslow, trigger);
        }

        /// <summary>
        /// RAVIFXFisher Created by Luis Guilherme Damiani. Converted to NinjaTrader by Elliott Wave.
        /// </summary>
        /// <returns></returns>
        public Indicator.RAVIFXFisher RAVIFXFisher(Data.IDataSeries input, int mAfast, int mAslow, double trigger)
        {
            if (InInitialize && input == null)
                throw new ArgumentException("You only can access an indicator with the default input/bar series from within the 'Initialize()' method");

            return _indicator.RAVIFXFisher(input, mAfast, mAslow, trigger);
        }

    }
}
#endregion
